import * as React from 'react';
import { Maybe } from '../../../common';
import { ColumnProps } from './';
import { Node } from '../../../state';
import { Tooltip, TooltipCopyCallback } from '../../';
import icon from '../../../icons/shield.svg';

export class ValidatorColumn extends React.Component<ColumnProps> {
  public static readonly label = 'Validator';
  public static readonly icon = icon;
  public static readonly width = 16;
  public static readonly setting = 'validator';
  public static readonly sortBy = ({ validator }: Node) => validator || '';

  private data: Maybe<string>;
  private copy: Maybe<TooltipCopyCallback>;

  public shouldComponentUpdate(nextProps: ColumnProps) {
    return this.data !== nextProps.node.validator;
  }

  render() {
    const { validator } = this.props.node;

    this.data = validator;

    if (!validator) {
      return <td className="Column">-</td>;
    }

    return (
      <td className="Column" onClick={this.onClick}>
        <Tooltip text={validator} copy={this.onCopy} />
      </td>
    );
  }

  private onCopy = (copy: TooltipCopyCallback) => {
    this.copy = copy;
  };

  private onClick = (event: React.MouseEvent) => {
    event.stopPropagation();

    if (this.copy != null) {
      this.copy();
    }
  };
}
